@@ -1,7 +1,7 @@
 /**
  * @file feedlist.c  subscriptions as an hierarchic tree
  *
- * Copyright (C) 2005-2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2011 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2005-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *	      
  * This program is free software; you can redistribute it and/or modify
@@ -29,22 +29,17 @@
 #include "feedlist.h"
 #include "folder.h"
 #include "itemlist.h"
-#include "net.h"
+#include "net_monitor.h"
 #include "node.h"
-#include "script.h"
 #include "update.h"
 #include "vfolder.h"
+#include "ui/feed_list_view.h"
 #include "ui/itemview.h"
 #include "ui/liferea_shell.h"
-#include "ui/ui_feedlist.h"
 #include "ui/ui_node.h"
-#include "ui/ui_subscription.h"
 #include "ui/ui_tray.h"
 #include "fl_sources/node_source.h"
-#include "notification/notification.h"
 
-static void feedlist_class_init	(FeedListClass *klass);
-static void feedlist_init	(FeedList *fl);
 static void feedlist_save	(void);
 
 #define FEEDLIST_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), FEEDLIST_TYPE, FeedListPrivate))
@@ -60,44 +55,16 @@ struct FeedListPrivate {
 	guint		saveTimer;	/**< timer id for delayed feed list saving */
 	guint		autoUpdateTimer; /**< timer id for auto update */
 
-	gboolean	loading;	/**< this flag prevents the feed list being saved before it is completely loaded */
+	gboolean	loading;	/**< prevents the feed list being saved before it is completely loaded */
 };
 
 #define ROOTNODE feedlist->priv->rootNode
 #define SELECTED feedlist->priv->selectedNode
 
-#define IS_SELECTED(node) (feedlist->priv->selectedNode == node)
-
 static GObjectClass *parent_class = NULL;
 static FeedList *feedlist = NULL;
 
-GType
-feedlist_get_type (void) 
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) 
-	{
-		static const GTypeInfo our_info = 
-		{
-			sizeof (FeedListClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) feedlist_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (FeedList),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) feedlist_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "FeedList",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (FeedList, feedlist, G_TYPE_OBJECT);
 
 static void
 feedlist_free_node (nodePtr node)
@@ -146,7 +113,7 @@ feedlist_auto_update (void *data)
 {
 	debug_enter ("feedlist_auto_update");
 
-	if (network_is_online ())
+	if (network_monitor_is_online ())
 		node_auto_update_subscription (ROOTNODE);
 	else
 		debug0 (DEBUG_UPDATE, "no update processing because we are offline!");
@@ -156,6 +123,12 @@ feedlist_auto_update (void *data)
 	return TRUE;
 }
 
+static void
+on_network_status_changed (gpointer instance, gboolean online, gpointer data)
+{
+	if (online) feedlist_auto_update (NULL);
+}
+
 /* This method is used to initialize the node states in the feed list */
 static void
 feedlist_init_node (nodePtr node) 
@@ -175,6 +148,8 @@ feedlist_init_node (nodePtr node)
 static void
 feedlist_init (FeedList *fl)
 {
+	gint	startup_feed_action;
+
 	debug_enter ("feedlist_init");
 	
 	/* 1. Prepare globally accessible singleton */
@@ -192,28 +167,27 @@ feedlist_init (FeedList *fl)
 	debug0 (DEBUG_CACHE, "Initializing node state");
 	feedlist_foreach (feedlist_init_node);
 
-	debug0 (DEBUG_GUI, "Notification setup");	
-	notification_enable (conf_get_bool_value (SHOW_POPUP_WINDOWS));
 	ui_tray_update ();
 
 	/* 4. Check if feeds do need updating. */
 	debug0 (DEBUG_UPDATE, "Performing initial feed update");
-	switch (conf_get_int_value (STARTUP_FEED_ACTION)) {
-		case 1: /* Update all feeds */
-			debug0 (DEBUG_UPDATE, "initial update: updating all feeds");
+	conf_get_int_value (STARTUP_FEED_ACTION, &startup_feed_action);
+	if (0 == startup_feed_action) {
+		/* Update all feeds */
+		if (network_monitor_is_online ()) {
+			debug0 (DEBUG_UPDATE, "initial update: updating all feeds");		
 			node_update_subscription (feedlist_get_root (), GUINT_TO_POINTER (0));
-			break;
-		case 2:
-			debug0 (DEBUG_UPDATE, "initial update: resetting feed counter");
-			feedlist_reset_update_counters (NULL);
-			break;
-		default:
-			debug0 (DEBUG_UPDATE, "initial update: using auto update");
-			/* default, which is to use the lastPoll times, does not need any actions here. */;
+		} else {
+			debug0 (DEBUG_UPDATE, "initial update: prevented because we are offline");
+		}
+	} else {
+		debug0 (DEBUG_UPDATE, "initial update: resetting feed counter");
+		feedlist_reset_update_counters (NULL);
 	}
 
 	/* 5. Start automatic updating */
 	feedlist->priv->autoUpdateTimer = g_timeout_add_seconds (10, feedlist_auto_update, NULL);
+	g_signal_connect (network_monitor_get (), "online-status-changed", G_CALLBACK (on_network_status_changed), NULL);
 
 	/* 6. Finally save the new feed list state */
 	feedlist->priv->loading = FALSE;
@@ -267,12 +241,8 @@ feedlist_is_writable (void)
 static void
 feedlist_update_node_counters (nodePtr node)
 {
-	if (node->needsRecount) {
-		if (IS_VFOLDER (node))
-			vfolder_update_counters (node);	/* simple vfolder only update */
-		else
-			node_update_counters (node);	/* update with parent propagation */
-	}
+	node_update_counters (node);	/* update with parent propagation */
+
 	if (node->needsUpdate)
 		ui_node_update (node->id);
 	if (node->children)
@@ -346,7 +316,6 @@ feedlist_reset_new_item_count (void)
 void
 feedlist_node_was_updated (nodePtr node, guint newCount)
 {
-	vfolder_foreach (vfolder_update_counters);			
 	node_update_counters (node);
 	feedlist_update_new_item_count (newCount);
 }
@@ -412,10 +381,7 @@ feedlist_node_added (nodePtr node)
 
 	feedlist_node_imported (node);
 	
-	ui_feedlist_select (node);
-	
-	if (node->subscription)
-		script_run_for_hook (SCRIPT_HOOK_NEW_SUBSCRIPTION);
+	feed_list_view_select (node);
 }
 
 void
@@ -430,7 +396,7 @@ feedlist_remove_node (nodePtr node)
 void
 feedlist_node_removed (nodePtr node)
 {
-	if (IS_SELECTED (node))
+	if (node == SELECTED)
 		feedlist_unselect ();
 		
 	/* First remove all children */
@@ -535,7 +501,7 @@ feedlist_unselect (void)
 	itemview_update ();
 		
 	itemlist_unload (FALSE /* mark all read */);
-	ui_feedlist_select (NULL);
+	feed_list_view_select (NULL);
 	liferea_shell_update_feed_menu (TRUE, FALSE, FALSE);
 	liferea_shell_update_allitems_actions (FALSE, FALSE);
 }
@@ -554,8 +520,6 @@ feedlist_selection_changed (nodePtr node)
 		if (0 != feedlist->priv->newCount)
 			feedlist_reset_new_item_count ();
 
-		script_run_for_hook (SCRIPT_HOOK_FEED_UNSELECT);
-
 		/* Unload visible items. */
 		itemlist_unload (TRUE);
 	
@@ -567,9 +531,6 @@ feedlist_selection_changed (nodePtr node)
 		} else {
 			itemview_clear ();
 		}
-		
-		if (SELECTED)
-			script_run_for_hook (SCRIPT_HOOK_FEED_SELECTED);
 	}
 
 	debug_exit ("feedlist_selection_changed");
