@@ -127,107 +127,6 @@ google_source_action_context_free(GoogleSourceActionCtxtPtr ctxt)
 	g_slice_free(struct GoogleSourceActionCtxt, ctxt);
 }
 
-static gchar* google_source_edit_get_cachefile (GoogleSourcePtr gsource) 
-{
-	return common_create_cache_filename ("cache" G_DIR_SEPARATOR_S "plugins", gsource->root->id, "savedactions.xml");
-}
-
-static void
-google_source_edit_export_helper (GoogleSourceActionPtr action, xmlTextWriterPtr writer) 
-{
-	xmlTextWriterStartElement (writer, BAD_CAST "action");
-
-	gchar* actionType = g_strdup_printf ("%d", action->actionType);
-	xmlTextWriterWriteElement (writer, BAD_CAST "action", actionType);
-	g_free (actionType);
-	if (action->feedUrl) 
-		xmlTextWriterWriteElement (writer, BAD_CAST "feedUrl", action->feedUrl);
-	if (action->guid) 
-		xmlTextWriterWriteElement (writer, BAD_CAST "guid", action->guid);
-	xmlTextWriterEndElement (writer);
-}
-
-void
-google_source_edit_export (GoogleSourcePtr gsource) 
-{ 
-	xmlTextWriterPtr writer;
-	gchar            *file = google_source_edit_get_cachefile (gsource);
-	writer = xmlNewTextWriterFilename (file, 0);
-	g_free (file);
-	file = NULL;
-	if (writer == NULL) {
-		g_warning ("Could not create edit cache file\n");
-		g_assert (FALSE);
-		return;
-	}
-	xmlTextWriterStartDocument (writer, NULL, "UTF-8", NULL);
-
-	xmlTextWriterStartElement (writer, BAD_CAST "actions");
-	xmlTextWriterWriteAttribute (writer, BAD_CAST "version", BAD_CAST PACKAGE_VERSION);
-
-	while (!g_queue_is_empty(gsource->actionQueue)) {
-		GoogleSourceActionPtr action = g_queue_pop_head (gsource->actionQueue);
-		google_source_edit_export_helper (action, writer);
-	}
-	
-	xmlTextWriterEndElement (writer);
-	xmlTextWriterEndDocument (writer);
-	xmlFreeTextWriter (writer);
-}
-
-static void
-google_source_edit_import_helper (xmlNodePtr match, gpointer userdata) 
-{
-	GoogleSourcePtr gsource = (GoogleSourcePtr) userdata ;
-	GoogleSourceActionPtr action;
-	xmlNodePtr cur; 
-
-	action = google_source_action_new () ;
-	
-	cur = match->children ; 
-	while (cur) {
-		xmlChar *content = xmlNodeGetContent (cur);
-		if (g_str_equal ((gchar*) cur->name, "action")) {
-			action->actionType = atoi (content) ;
-		} else if (g_str_equal ((gchar*) cur->name, "guid")){ 
-			action->guid = g_strdup ((gchar*) content);
-		} else if (g_str_equal ((gchar*) cur->name, "feedUrl")) {
-			action->feedUrl = g_strdup ((gchar*) content);
-		}
-		if (content) xmlFree (content);
-		cur = cur->next;
-	}
-
-	debug3 (DEBUG_CACHE, "Found edit request: %d %s %s \n", action->actionType, action->feedUrl, action->guid);
-	google_source_edit_push (gsource, action, FALSE);
-}
-
-void
-google_source_edit_import (GoogleSourcePtr gsource) 
-{
-	gchar* file = google_source_edit_get_cachefile (gsource);
-
-	if (!g_file_test(file, G_FILE_TEST_IS_REGULAR)) {
-		debug0 (DEBUG_UPDATE, "GoogleSource: saved actions file not found.");
-		g_free (file);
-		return;
-	}
-
-	xmlDocPtr doc = xmlReadFile (file, NULL, 0);
-	if (doc == NULL) {
-		g_free(file);
-		return; 
-	}
-
-	xmlNodePtr root = xmlDocGetRootElement (doc);
-	
-	xpath_foreach_match (root, "/actions/action", google_source_edit_import_helper, gsource);
-
-	g_unlink (file); 
-	xmlFreeDoc (doc);
-	g_free (file); 	
-}
-
 static void
 google_source_edit_action_complete (const struct updateResult* const result, gpointer userdata, updateFlags flags) 
 { 
