@@ -24,7 +24,6 @@
 #include <libxml/xpathInternals.h>
 
 #include "common.h"
-#include "conf.h"
 #include "debug.h"
 #include "xml.h"
 
@@ -87,26 +86,6 @@ google_source_xml_unlink_node (xmlNodePtr node, gpointer data)
 	xmlFreeNode (node);
 }
 
-void 
-google_source_item_set_flag (nodePtr node, itemPtr item, gboolean newStatus)
-{
-	const gchar* sourceUrl = metadata_list_get (item->metadata, "GoogleBroadcastOrigFeed");
-	if (!sourceUrl) sourceUrl = node->subscription->source;
-	nodePtr root = google_source_get_root_from_node (node);
-	google_source_edit_mark_starred ((GoogleSourcePtr)root->data, item->sourceId, sourceUrl, newStatus);
-	item_flag_state_changed(item, newStatus);
-}
-void
-google_source_item_mark_read (nodePtr node, itemPtr item, 
-                              gboolean newStatus)
-{
-	const gchar* sourceUrl = metadata_list_get(item->metadata, "GoogleBroadcastOrigFeed");
-	if (!sourceUrl) sourceUrl = node->subscription->source;
-	nodePtr root = google_source_get_root_from_node (node);
-	google_source_edit_mark_read ((GoogleSourcePtr)root->data, item->sourceId, sourceUrl, newStatus);
-	item_read_state_changed(item, newStatus);
-}
-
 static void
 google_source_set_orig_source(const xmlNodePtr node, gpointer userdata)
 {
@@ -190,10 +169,11 @@ google_source_load_item_from_sourceid (nodePtr node, gchar *sourceId, GHashTable
 	itemset_free (itemset);
 	return NULL;
 }
+
 static void
 google_source_item_retrieve_status (const xmlNodePtr entry, subscriptionPtr subscription, GHashTable *cache)
 {
-	GoogleSourcePtr gsource = (GoogleSourcePtr) google_source_get_root_from_node (subscription->node)->data ;
+	GoogleSourcePtr gsource = (GoogleSourcePtr) node_source_root_from_node (subscription->node)->data ;
 	xmlNodePtr      xml;
 	nodePtr         node = subscription->node;
 	xmlChar         *id;
@@ -253,12 +233,11 @@ google_feed_subscription_process_update_result (subscriptionPtr subscription, co
 		resultCopy->source = g_strdup (result->source); 
 		resultCopy->httpstatus = result->httpstatus;
 		resultCopy->contentType = g_strdup (result->contentType);
-		resultCopy->retriesCount = result->retriesCount ;
 		g_free (resultCopy->updateState);
 		resultCopy->updateState = update_state_copy (result->updateState);
 		
 		/* update the XML by removing 'read', 'reading-list' etc. as labels. */
-		xmlDocPtr doc = xml_parse (result->data, result->size, FALSE, NULL);
+		xmlDocPtr doc = xml_parse (result->data, result->size, NULL);
 		xmlXPathContextPtr xpathCtxt = xmlXPathNewContext (doc) ;
 		xmlXPathRegisterNs (xpathCtxt, "atom", "http://www.w3.org/2005/Atom");
 		google_source_xpath_foreach_match ("/atom:feed/atom:entry/atom:category[@scheme='http://www.google.com/reader/']", xpathCtxt, google_source_xml_unlink_node, NULL);
@@ -296,7 +275,7 @@ google_feed_subscription_process_update_result (subscriptionPtr subscription, co
 	   by getting the newCount first and setting it again later. */
 	guint newCount = feedlist_get_new_item_count ();
 
-	xmlDocPtr doc = xml_parse (result->data, result->size, FALSE, NULL);
+	xmlDocPtr doc = xml_parse (result->data, result->size, NULL);
 	if (doc) {		
 		xmlNodePtr root = xmlDocGetRootElement (doc);
 		xmlNodePtr entry = root->children ; 
@@ -325,18 +304,16 @@ google_feed_subscription_process_update_result (subscriptionPtr subscription, co
 	debug_end_measurement (DEBUG_UPDATE, "time taken to update statuses");
 }
 
-
-
 static gboolean
 google_feed_subscription_prepare_update_request (subscriptionPtr subscription, 
                                                  struct updateRequest *request)
 {
 	debug0 (DEBUG_UPDATE, "preparing google reader feed subscription for update\n");
-	GoogleSourcePtr gsource = (GoogleSourcePtr) google_source_get_root_from_node (subscription->node)->data; 
+	GoogleSourcePtr gsource = (GoogleSourcePtr) node_source_root_from_node (subscription->node)->data; 
 	
 	g_assert(gsource); 
 	if (gsource->loginState == GOOGLE_SOURCE_STATE_NONE) { 
-		subscription_update (google_source_get_root_from_node (subscription->node)->subscription, 0) ;
+		subscription_update (node_source_root_from_node (subscription->node)->subscription, 0) ;
 		return FALSE;
 	}
 	debug0 (DEBUG_UPDATE, "Setting cookies for a Google Reader subscription");
