@@ -1,7 +1,7 @@
 /**
  * @file node_source.c  generic node source provider implementation
  * 
- * Copyright (C) 2005-2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2010 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "item_state.h"
 #include "node.h"
 #include "node_type.h"
+#include "ui/icons.h"
 #include "ui/liferea_dialog.h"
 #include "ui/ui_common.h"
 #include "ui/ui_node.h"
@@ -39,10 +40,19 @@
 #include "fl_sources/dummy_source.h"
 #include "fl_sources/google_source.h"
 #include "fl_sources/opml_source.h"
-#include "notification/notification.h"
+#include "fl_sources/ttrss_source.h"
 
 static GSList	*nodeSourceTypes = NULL;
 
+nodePtr
+node_source_root_from_node (nodePtr node)
+{ 
+	while (node->parent->source == node->source) 
+		node = node->parent;
+		
+	return node;
+}
+
 static nodeSourceTypePtr
 node_source_type_find (const gchar *typeStr, guint capabilities)
 {
@@ -63,19 +73,6 @@ node_source_type_find (const gchar *typeStr, guint capabilities)
 static gboolean
 node_source_type_register (nodeSourceTypePtr type)
 {
-	/* check feed list provider plugin version */
-	if (NODE_SOURCE_TYPE_API_VERSION != type->api_version) {
-		debug3 (DEBUG_PLUGINS, "feed list source API version mismatch: \"%s\" has version %d should be %d", type->name, type->api_version, NODE_SOURCE_TYPE_API_VERSION);
-		return FALSE;
-	} 
-
-	/* check if all mandatory functions are provided */
-	if (!(type->source_type_init &&
-	      type->source_type_deinit)) {
-		debug1 (DEBUG_PLUGINS, "mandatory functions missing: \"%s\"", type->name);
-		return FALSE;
-	}
-
 	/* allow the plugin to initialize */
 	type->source_type_init ();
 
@@ -97,6 +94,7 @@ node_source_setup_root (void)
 	node_source_type_register (dummy_source_get_type ());
 	node_source_type_register (opml_source_get_type ());
 	node_source_type_register (google_source_get_type ());
+	node_source_type_register (ttrss_source_get_type ());
 
 	type = node_source_type_find (NULL, NODE_SOURCE_CAPABILITY_IS_ROOT);
 	if (!type) 
@@ -242,7 +240,7 @@ ui_node_source_type_dialog (void)
 	}		
 
 	/* set up the dialog */
-	dialog = liferea_dialog_new ("node_source.glade", "node_source_type_dialog");
+	dialog = liferea_dialog_new ("node_source.ui", "node_source_type_dialog");
 
 	treestore = gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
 	
@@ -370,7 +368,6 @@ node_source_remove (nodePtr node)
 	if (NULL != NODE_SOURCE_TYPE (node)->source_delete)
 		NODE_SOURCE_TYPE (node)->source_delete (node);
 		
-	notification_node_removed (node);
 	ui_node_remove_node (node);
 }
 
@@ -399,11 +396,12 @@ node_source_get_node_type (void)
 		/* derive the node source node type from the folder node type */
 		nodeType = (nodeTypePtr) g_new0 (struct nodeType, 1);
 		nodeType->id			= "source";
-		nodeType->icon			= icons[ICON_DEFAULT];
+		nodeType->icon			= icon_get (ICON_DEFAULT);
 		nodeType->capabilities		= NODE_CAPABILITY_SHOW_UNREAD_COUNT |
 						  NODE_CAPABILITY_SHOW_ITEM_FAVICONS |
 						  NODE_CAPABILITY_UPDATE_CHILDS |
 						  NODE_CAPABILITY_UPDATE |
+						  NODE_CAPABILITY_UPDATE_FAVICON |
 						  NODE_CAPABILITY_ADD_CHILDS |
 						  NODE_CAPABILITY_REMOVE_CHILDS;
 		nodeType->import		= node_source_import;
