@@ -1,7 +1,7 @@
 /**
  * @file folder.c  sub folders for hierarchic node sources
  * 
- * Copyright (C) 2006-2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2006-2010 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,15 +18,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "folder.h"
+
 #include "common.h"
 #include "debug.h"
 #include "export.h"
 #include "feedlist.h"
-#include "folder.h"
 #include "itemset.h"
 #include "node.h"
-#include "vfolder.h"
-#include "ui/ui_common.h"
+#include "ui/icons.h"
 #include "ui/ui_folder.h"
 #include "ui/ui_node.h"
 
@@ -81,19 +81,21 @@ folder_save (nodePtr node)
 }
 
 static void
-folder_add_child_unread_count (nodePtr node, gpointer user_data)
+folder_add_child_update_counters (nodePtr node, gpointer user_data)
 {
 	guint	*unreadCount = (guint *)user_data;
 
-	if (!IS_VFOLDER (node))
-		*unreadCount += node->unreadCount;
+	*unreadCount += node->unreadCount;
 }
 
 static void
-folder_update_unread_count(nodePtr node)
+folder_update_counters (nodePtr node)
 {
+	/* We never need a total item count for folders.
+	   Only the total unread count is interesting */
+	node->itemCount = 0;
 	node->unreadCount = 0;
-	node_foreach_child_data (node, folder_add_child_unread_count, &node->unreadCount);
+	node_foreach_child_data (node, folder_add_child_update_counters, &node->unreadCount);
 }
 
 static void
@@ -120,13 +122,13 @@ folder_get_node_type (void)
 		folder_export,
 		folder_load,
 		folder_save,
-		folder_update_unread_count,
+		folder_update_counters,
 		folder_remove,
 		node_default_render,
 		ui_folder_add,
 		ui_node_rename
 	};
-	fnti.icon = icons[ICON_FOLDER];
+	fnti.icon = icon_get (ICON_FOLDER);
 
 	return &fnti; 
 }
@@ -149,7 +151,7 @@ root_get_node_type (void)
 		folder_export,
 		folder_load,
 		folder_save,
-		folder_update_unread_count,
+		folder_update_counters,
 		folder_remove,
 		node_default_render,
 		ui_folder_add,
