@@ -1,7 +1,7 @@
 /**
  * @file newsbin.c  news bin node type implementation
  * 
- * Copyright (C) 2006-2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2006-2010 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,9 @@
 #include "metadata.h"
 #include "render.h"
 #include "vfolder.h"
-#include "ui/liferea_dialog.h"
-#include "ui/ui_feedlist.h"
+#include "ui/icons.h"
 #include "ui/ui_node.h"
+#include "ui/liferea_dialog.h"
 
 static GtkWidget *newnewsbindialog = NULL;
 static GSList * newsbin_list = NULL;
@@ -67,14 +67,11 @@ newsbin_remove (nodePtr node)
 static gchar *
 newsbin_render (nodePtr node)
 {
-	renderParamPtr	params;
 	gchar		*output = NULL;
 	xmlDocPtr	doc;
 
 	doc = feed_to_xml(node, NULL);
-	params = render_parameter_new();
-	render_parameter_add(params, "pixmapsDir='file://" PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "'");
-	output = render_xml(doc, "newsbin", params);
+	output = render_xml(doc, "newsbin", NULL);
 	xmlFreeDoc(doc);
 
 	return output;
@@ -153,7 +150,7 @@ newsbin_get_node_type (void)
 		                                  NODE_CAPABILITY_SHOW_UNREAD_COUNT |
 		                                  NODE_CAPABILITY_SHOW_ITEM_COUNT;
 		nodeType->id			= "newsbin";
-		nodeType->icon			= icons[ICON_NEWSBIN];
+		nodeType->icon			= icon_get (ICON_NEWSBIN);
 		nodeType->load			= feed_get_node_type()->load;		
 		nodeType->import		= newsbin_import;
 		nodeType->export		= feed_get_node_type()->export;
