@@ -1,7 +1,7 @@
 /**
  * @file ns_dc.c Dublin Core support for RSS and Atom
  *
- * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2010 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,14 +18,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
-#define _XOPEN_SOURCE	600 	/* glibc2 needs this (man strptime) */
-
 #include "ns_dc.h"
+
+#include "date.h"
 #include "common.h"
 #include "metadata.h"
 
@@ -120,7 +115,7 @@ static const gchar * mapToFeedMetadata[] = {
 				  };
 
 static const gchar * mapToItemMetadata[] = {
-				 	"itemTitle",		/* title */ 
+				 	NULL,			/* title */ 
 					"creator",		/* creator */
 					"category",		/* subject */
 					"description",		/* description */
@@ -146,22 +141,32 @@ parse_tag (feedParserCtxtPtr ctxt, xmlNodePtr cur, gboolean isFeedTag)
 	const gchar	*mapping;
 	gboolean	isNotEmpty;
 	
-	/* special handling for the ISO 8601 date item tags */
 	if (!isFeedTag) {
+		/* special handling for the ISO 8601 date item tags */
 		if (!xmlStrcmp (BAD_CAST "date", cur->name)) {
- 			if (NULL != (date = common_utf8_fix ((gchar *)xmlNodeListGetString (cur->doc, cur->xmlChildrenNode, 1)))) {
-				i = parseISO8601Date (date);
+ 			if (NULL != (date = (gchar *)xmlNodeListGetString (cur->doc, cur->xmlChildrenNode, 1))) {
+				i = date_parse_ISO8601 (date);
 				ctxt->item->time = i;
 				g_free (date);
 			}
 			return;
 		}
+
+		/* special handling for item titles */
+		if(!xmlStrcmp (BAD_CAST "title", cur->name)) {
+			value = (gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1);
+			if(value) {
+				item_set_title(ctxt->item, value);
+				g_free(value);
+			}
+			return;
+		}
 	}
 
 	/* compare with each possible tag name */
 	for (i = 0; taglist[i] != NULL; i++) {
 		if (!xmlStrcmp ((const xmlChar *)taglist[i], cur->name)) {
- 			value = common_utf8_fix ((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
+ 			value = (gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1);
 	 		if (value) {
 				/* check if value consist of whitespaces only */				
 				for (j = 0, tmp = value, isNotEmpty = FALSE; j < g_utf8_strlen (value, -1); j++) {
