@@ -1,7 +1,8 @@
 /**
  * @file rule_editor.c  rule editing dialog functionality
  *
- * Copyright (C) 2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2008-2011 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2009 Hubert Figuiere <hub@figuiere.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,17 +20,22 @@
  */
  
 #include "ui/rule_editor.h"
+#include "ui/ui_common.h"
 
 #include "rule.h"
 
-static void rule_editor_class_init	(RuleEditorClass *klass);
-static void rule_editor_init		(RuleEditor *ld);
+/*
+   A 'rule editor' is a dialog allowing editing arbitrary filtering
+   'rules'. The rules edited are loaded from an 'item set' which
+   can belong to a 'search folder' or an 'item list' filter. 
+
+   The rule editing is independant of any search folder handling.
+*/
 
 #define RULE_EDITOR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), RULE_EDITOR_TYPE, RuleEditorPrivate))
 
 struct RuleEditorPrivate {
 	GtkWidget	*root;		/**< root widget */
-	vfolderPtr	vfolder;	/**< the search folder being edited (FIXME: why do we need this?) */
 	GSList		*newRules;	/**< new list of rules currently in editing */
 };
 
@@ -42,33 +48,7 @@ struct changeRequest {
 
 static GObjectClass *parent_class = NULL;
 
-GType
-rule_editor_get_type (void) 
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) 
-	{
-		static const GTypeInfo our_info = 
-		{
-			sizeof (RuleEditorClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) rule_editor_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (RuleEditor),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) rule_editor_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "RuleEditor",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (RuleEditor, rule_editor, G_TYPE_OBJECT);
 
 static void
 rule_editor_finalize (GObject *object)
@@ -122,51 +102,37 @@ on_rulevalue_changed (GtkEditable *editable, gpointer user_data)
 }
 
 /* callback for rule additive option menu */
+
 static void
-on_rule_set_additive (GtkOptionMenu *optionmenu, gpointer user_data)
+on_rule_changed_additive (GtkComboBox *optionmenu, gpointer user_data)
 {
 	rulePtr rule = (rulePtr)user_data;
-	
-	rule->additive = TRUE;
+	gint active = gtk_combo_box_get_active (optionmenu);
+
+	rule->additive = ((active==0) ? TRUE : FALSE);
 }
 
-/* callback for rule additive option menu */
-static void
-on_rule_unset_additive (GtkOptionMenu *optionmenu, gpointer user_data)
-{
-	rulePtr rule = (rulePtr)user_data;
-	
-	rule->additive = FALSE;
-}
 
 /* sets up the widgets for a single rule */
 static void
 rule_editor_setup_widgets (struct changeRequest *changeRequest, rulePtr rule)
 {
-	GtkWidget	*widget, *menu;
+	GtkWidget	*widget;
 	ruleInfoPtr	ruleInfo;
 
-	ruleInfo = ruleFunctions + changeRequest->rule;
+	ruleInfo = g_slist_nth_data (rule_get_available_rules (), changeRequest->rule);
 	g_object_set_data (G_OBJECT (changeRequest->paramHBox), "rule", rule);
 			
 	/* remove of old widgets */
 	gtk_container_foreach (GTK_CONTAINER (changeRequest->paramHBox), rule_editor_destroy_param_widget, NULL);
 
 	/* add popup menu for selection of positive or negative logic */
-	menu = gtk_menu_new ();
-	
-	widget = gtk_menu_item_new_with_label (ruleInfo->positive);
-	gtk_container_add (GTK_CONTAINER (menu), widget);
-	g_signal_connect (G_OBJECT (widget), "activate", G_CALLBACK (on_rule_set_additive), rule);
-	
-	widget = gtk_menu_item_new_with_label (ruleInfo->negative);
-	gtk_container_add (GTK_CONTAINER (menu), widget);
-	g_signal_connect (G_OBJECT (widget), "activate", G_CALLBACK (on_rule_unset_additive), rule);
-	
-	gtk_menu_set_active (GTK_MENU (menu), (rule->additive)?0:1);
-	
-	widget = gtk_option_menu_new ();
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (widget), menu);	
+
+	widget = gtk_combo_box_new_text ();
+	gtk_combo_box_append_text ((GtkComboBox*)widget, ruleInfo->positive);
+	gtk_combo_box_append_text ((GtkComboBox*)widget, ruleInfo->negative);
+	gtk_combo_box_set_active ((GtkComboBox*)widget, (rule->additive)?0:1);
+	g_signal_connect (G_OBJECT (widget), "changed", G_CALLBACK (on_rule_changed_additive), rule);
 	gtk_widget_show_all (widget);
 	gtk_box_pack_start (GTK_BOX (changeRequest->paramHBox), widget, FALSE, FALSE, 0);
 		
@@ -182,29 +148,39 @@ rule_editor_setup_widgets (struct changeRequest *changeRequest, rulePtr rule)
 	}
 }
 
-/* callback for rule type option menu */
+
 static void
-on_ruletype_changed (GtkOptionMenu *optionmenu, gpointer user_data)
+do_ruletype_changed (struct changeRequest	*changeRequest)
 {
-	struct changeRequest	*changeRequest = (struct changeRequest *)user_data;
 	ruleInfoPtr		ruleInfo;
 	rulePtr			rule;
-	
-	if (!changeRequest)
-		return;
-	
+
 	rule = g_object_get_data (G_OBJECT (changeRequest->paramHBox), "rule");
 	if (rule) {
 		changeRequest->editor->priv->newRules = g_slist_remove (changeRequest->editor->priv->newRules, rule);
 		rule_free (rule);
 	}
-	ruleInfo = ruleFunctions + changeRequest->rule;
-	rule = rule_new (changeRequest->editor->priv->vfolder, ruleInfo->ruleId, "", TRUE);
+	ruleInfo = g_slist_nth_data (rule_get_available_rules (), changeRequest->rule);
+	rule = rule_new (ruleInfo->ruleId, "", TRUE);
 	changeRequest->editor->priv->newRules = g_slist_append (changeRequest->editor->priv->newRules, rule);
 	
 	rule_editor_setup_widgets (changeRequest, rule);
 }
 
+/* callback for rule type option menu */
+static void
+on_ruletype_changed (GtkComboBox *optionmenu, gpointer user_data)
+{
+	struct changeRequest	*changeRequest = NULL;
+	GtkTreeIter iter;
+	
+	if (gtk_combo_box_get_active_iter (optionmenu, &iter)) {
+		gtk_tree_model_get (gtk_combo_box_get_model (optionmenu), &iter, 1, &changeRequest, -1);
+		if (changeRequest)
+			do_ruletype_changed (changeRequest);
+	}
+}
+
 /* callback for each rules remove button */
 static void
 on_ruleremove_clicked (GtkButton *button, gpointer user_data)
@@ -224,21 +200,22 @@ on_ruleremove_clicked (GtkButton *button, gpointer user_data)
 void
 rule_editor_add_rule (RuleEditor *re, rulePtr rule)
 {
-	GtkWidget		*hbox, *hbox2, *menu, *widget;
+	GSList			*ruleIter;
+	GtkWidget		*hbox, *hbox2, *widget;
+	GtkListStore		*store;
 	struct changeRequest	*changeRequest, *selected = NULL;
-	ruleInfoPtr		ruleInfo;
-	gint			i;
-	
+	gint			i = 0, active = 0;
+
 	hbox = gtk_hbox_new (FALSE, 2);	/* hbox to contain all rule widgets */
 	hbox2 = gtk_hbox_new (FALSE, 2);	/* another hbox where the rule specific widgets are added */
-
-	if (nrOfRuleFunctions == 0)
-		rule_init();
 		
 	/* set up the rule type selection popup */
-	menu = gtk_menu_new ();
-	for (i = 0, ruleInfo = ruleFunctions; i < nrOfRuleFunctions; i++, ruleInfo++) {
-	
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
+	ruleIter = rule_get_available_rules ();
+	while (ruleIter) {
+		ruleInfoPtr ruleInfo = (ruleInfoPtr)ruleIter->data;
+		GtkTreeIter iter;
+		
 		/* we add a change request to each popup option */
 		changeRequest = g_new0 (struct changeRequest, 1);
 		changeRequest->paramHBox = hbox2;
@@ -249,27 +226,35 @@ rule_editor_add_rule (RuleEditor *re, rulePtr rule)
 			selected = changeRequest;
 		
 		/* build the menu option */
-		widget = gtk_menu_item_new_with_label (ruleInfo->title);
-		gtk_container_add (GTK_CONTAINER (menu), widget);
-		g_signal_connect (G_OBJECT (widget), "activate", G_CALLBACK (on_ruletype_changed), changeRequest);
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter, 0, ruleInfo->title, 1, changeRequest, -1);
 
 		if (rule) {
 			if (ruleInfo == rule->ruleInfo) {
 				selected = changeRequest;
-				gtk_menu_set_active (GTK_MENU (menu), i);
+				active = i;
 			}
 		}
+		
+		ruleIter = g_slist_next (ruleIter);
+		i++;
 	}
-	widget = gtk_option_menu_new ();
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (widget), menu);
+	widget = gtk_combo_box_new ();
+	ui_common_setup_combo_text (GTK_COMBO_BOX (widget), 0);
+
+	gtk_combo_box_set_model (GTK_COMBO_BOX (widget), GTK_TREE_MODEL (store));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), active);
+	g_signal_connect (G_OBJECT (widget), "changed", G_CALLBACK (on_ruletype_changed), NULL);
+
+
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
 	
 	if (!rule) {
 		/* fake a rule type change to initialize parameter widgets */
-		on_ruletype_changed (GTK_OPTION_MENU (widget), selected);
+		do_ruletype_changed (selected);
 	} else {
-		rulePtr newRule = rule_new (rule->vp, rule->ruleInfo->ruleId, rule->value, rule->additive);
+		rulePtr newRule = rule_new (rule->ruleInfo->ruleId, rule->value, rule->additive);
 
 		/* set up widgets with existing rule type and value */
 		rule_editor_setup_widgets (selected, newRule);
@@ -293,7 +278,7 @@ rule_editor_add_rule (RuleEditor *re, rulePtr rule)
 }
 
 RuleEditor *
-rule_editor_new (vfolderPtr vfolder) 
+rule_editor_new (itemSetPtr itemset) 
 {
 	RuleEditor	*re;
 	GSList		*iter;
@@ -302,10 +287,9 @@ rule_editor_new (vfolderPtr vfolder)
 	
 	/* Set up rule list vbox */
 	re->priv->root = gtk_vbox_new (FALSE, 0);
-	re->priv->vfolder = vfolder;	/* FIXME: why do we need this? */
 	
 	/* load rules into dialog */	
-	iter = vfolder->rules;
+	iter = itemset->rules;
 	while (iter) {
 		rule_editor_add_rule (re, (rulePtr)(iter->data));
 		iter = g_slist_next (iter);
@@ -317,29 +301,26 @@ rule_editor_new (vfolderPtr vfolder)
 }
 
 void
-rule_editor_save (RuleEditor *re, vfolderPtr vfolder)
+rule_editor_save (RuleEditor *re, itemSetPtr itemset)
 {
 	GSList	*iter;
 	
 	/* delete all old rules */	
-	iter = vfolder->rules;
+	iter = itemset->rules;
 	while (iter) {
 		rule_free ((rulePtr)iter->data);
 		iter = g_slist_next (iter);
 	}
-	g_slist_free (vfolder->rules);
-	vfolder->rules = NULL;
+	g_slist_free (itemset->rules);
+	itemset->rules = NULL;
 	
 	/* and add all rules from editor */
 	iter = re->priv->newRules;
 	while (iter) {
 		rulePtr rule = (rulePtr)iter->data;
-		vfolder_add_rule (vfolder, rule->ruleInfo->ruleId, rule->value, rule->additive);
+		itemset_add_rule (itemset, rule->ruleInfo->ruleId, rule->value, rule->additive);
 		iter = g_slist_next (iter);
 	}
-
-/* FIXME: move the following code from search_folder_dialog.c and search_dialog.c here:
-	vfolder->anyMatch = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (re->priv->anyRuleRadioBtn));	*/
 }
 
 GtkWidget *
