@@ -1,7 +1,7 @@
 /**
- * @file ui_dnd.c everything concerning DnD
+ * @file ui_dnd.c everything concerning Drag&Drop
  *
- * Copyright (C) 2003-2007 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2011 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,10 +22,10 @@
 #include "common.h"
 #include "feed.h"
 #include "feedlist.h"
+#include "folder.h"
 #include "debug.h"
-#include "conf.h"
-#include "ui/ui_feedlist.h"
-#include "ui/ui_itemlist.h"
+#include "ui/item_list_view.h"
+#include "ui/feed_list_view.h"
 #include "ui/ui_node.h"
 #include "ui/ui_dnd.h"
 #include "fl_sources/node_source.h"
@@ -80,10 +80,13 @@ ui_dnd_feed_draggable (GtkTreeDragSource *drag_source, GtkTreePath *path)
 static gboolean
 ui_dnd_feed_drop_possible (GtkTreeDragDest *drag_dest, GtkTreePath *dest_path, GtkSelectionData *selection_data)
 {
+	GtkTreeModel	*model = NULL;
+	GtkTreePath	*src_path = NULL;
 	GtkTreeIter	iter;
-	nodePtr		node;
+	nodePtr		sourceNode, targetNode;
 	
 	debug1 (DEBUG_GUI, "DnD check if feed dropping is possible (%d)", dest_path);
+
 		   	
 	if (!(old_feed_drop_possible) (drag_dest, dest_path, selection_data))
 		return FALSE;
@@ -91,17 +94,34 @@ ui_dnd_feed_drop_possible (GtkTreeDragDest *drag_dest, GtkTreePath *dest_path, G
 	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (drag_dest), &iter, dest_path))
 		return FALSE;
 
-	/* If we get an iterator it's either a possible dropping
+	/* Try to get an iterator, if we get none it means either feed list
+	   root or an "Empty" node. Both cases are fine */
+	gtk_tree_model_get (GTK_TREE_MODEL (drag_dest), &iter, FS_PTR, &targetNode, -1);
+	if (!targetNode)
+		return TRUE;
+
+	/* If we got an iterator it's either a possible dropping
 	   candidate (a folder or source node to drop into, or a
 	   iterator to insert after). In any case we have to check
 	   if it is a writeable node source. */
 
-	gtk_tree_model_get (GTK_TREE_MODEL (drag_dest), &iter, FS_PTR, &node, -1);
-
-	/* never drag nodes of read-only subscription lists */
-	if (node && !(NODE_SOURCE_TYPE (node)->capabilities & NODE_SOURCE_CAPABILITY_WRITABLE_FEEDLIST))
+	/* never drop into read-only subscription node sources */
+	if (!(NODE_SOURCE_TYPE (targetNode)->capabilities & NODE_SOURCE_CAPABILITY_WRITABLE_FEEDLIST))
 		return FALSE;
 
+	/* never drag folders into non-hierarchic node sources */
+	if (!gtk_tree_get_row_drag_data (selection_data, &model, &src_path))
+		return TRUE;
+
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, src_path)) {
+		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, FS_PTR, &sourceNode, -1);
+
+		if (IS_FOLDER(sourceNode) && !(NODE_SOURCE_TYPE (targetNode)->capabilities & NODE_SOURCE_CAPABILITY_HIERARCHIC_FEEDLIST))
+			return FALSE;
+	}
+
+	gtk_tree_path_free (src_path);
+
 	return TRUE;
 }
 
@@ -132,6 +152,7 @@ ui_dnd_feed_drag_data_received (GtkTreeDragDest *drag_dest, GtkTreePath *dest, G
 			if (gtk_tree_model_iter_parent (GTK_TREE_MODEL (drag_dest), &parentIter, &iter)) {
 				gtk_tree_model_get (GTK_TREE_MODEL (drag_dest), &parentIter, FS_PTR, &newParent, -1);
 			} else {
+				debug0 (DEBUG_GUI, "Defaulting to feed list root as drop target");
 				gtk_tree_model_get_iter_first (GTK_TREE_MODEL (drag_dest), &parentIter);
 				newParent = feedlist_get_root ();
 			}
@@ -192,7 +213,6 @@ ui_dnd_feed_drag_data_received (GtkTreeDragDest *drag_dest, GtkTreePath *dest, G
 			node_update_counters (newParent);
 			
 			feedlist_schedule_save ();
-			ui_itemlist_prefocus ();
 		}
 	}
 						      
