@@ -2,7 +2,8 @@
  * @file ui_prefs.c program preferences
  *
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
- * Copyright (C) 2004-2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2004-2010 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2009 Hubert Figuiere <hub@figuiere.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,20 +29,23 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "browser.h"
 #include "common.h"
 #include "conf.h"
 #include "enclosure.h"
 #include "favicon.h"
 #include "feedlist.h"
+#include "folder.h"
 #include "itemlist.h"
 #include "social.h"
 #include "ui/enclosure_list_view.h"
+#include "ui/ui_indicator.h"
+#include "ui/item_list_view.h"
 #include "ui/liferea_dialog.h"
 #include "ui/liferea_shell.h"
 #include "ui/ui_common.h"
-#include "ui/ui_itemlist.h"
+#include "ui/itemview.h"
 #include "ui/ui_tray.h"
-#include "notification/notification.h"
 
 /* file type tree store column ids */
 enum fts_columns {
@@ -53,7 +57,6 @@ enum fts_columns {
 
 extern GSList *htmlviewPlugins;
 extern GSList *bookmarkSites;	/* from social.c */
-extern GSList *linkSearchSites;	/* from social.c */
 
 static GtkWidget *prefdialog = NULL;
 
@@ -68,48 +71,6 @@ static struct enclosureDownloadTool enclosure_download_commands[] = {
 /** order must match enclosure_download_commands[] */
 static gchar *enclosure_download_tool_options[] = { "wget", "curl", "gwget", "kget", NULL };
 
-static struct browser browsers[] = {
-	{
-		"gnome", N_("GNOME Default Browser"), "gnome-open %s", 
-		NULL, NULL,
-		NULL, NULL,
-		NULL, NULL
-	},
-	{
-		/* tested with SeaMonkey 1.0.6 */
-		"mozilla", "Mozilla", "mozilla %s",
-		NULL, "mozilla -remote openURL(%s)",
-		NULL, "mozilla -remote 'openURL(%s,new-window)'",
-		NULL, "mozilla -remote 'openURL(%s,new-tab)'"
-	},
-	{
-		/* tested with Firefox 1.5 and 2.0 */
-		"firefox", "Firefox","firefox \"%s\"",
-		NULL, "firefox -a firefox -remote \"openURL(%s)\"",
-		NULL, "firefox -a firefox -remote 'openURL(%s,new-window)'",
-		NULL, "firefox -a firefox -remote 'openURL(%s,new-tab)'"
-	},
-	{
-		"opera", "Opera","opera \"%s\"",
-		"opera \"%s\"", "opera -remote \"openURL(%s)\"",
-		"opera -newwindow \"%s\"", NULL,
-		"opera -newpage \"%s\"", NULL
-	},
-	{
-		"epiphany", "Epiphany","epiphany \"%s\"",
-		NULL, NULL,
-		"epiphany \"%s\"", NULL,
-		"epiphany -n \"%s\"", NULL
-	},
-	{
-		"konqueror", "Konqueror", "kfmclient openURL \"%s\"",
-		NULL, NULL,
-		NULL, NULL,
-		NULL, NULL
-	},
-	{	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL }
-};
-
 /** GConf representation of toolbar styles */
 static gchar * gui_toolbar_style_values[] = { "", "both", "both-horiz", "icons", "text", NULL };
 
@@ -122,13 +83,6 @@ static gchar * gui_toolbar_style_options[] = {
 	NULL
 };
 
-static gchar * startup_update_options[] = {
-	N_("Update out-dated feeds"),
-	N_("Force update of all feeds"),
-	N_("No feed update at all"),
-	NULL
-};
-
 /* Note: these update interval literal should be kept in sync with the 
    ones in ui_subscription.c! */
     
@@ -146,83 +100,15 @@ static gchar * browser_skim_key_options[] = {
 	NULL
 };
 
-gchar *
-prefs_get_browser_command (struct browser *browser, gboolean remote, gboolean fallback)
-{
-	gchar	*cmd = NULL;
-	gchar	*libname;
-	gint	place = conf_get_int_value (BROWSER_PLACE);
-
-	/* check for manual browser command */
-	libname = conf_get_str_value (BROWSER_ID);
-	if (g_str_equal (libname, "manual")) {
-		/* retrieve user defined command... */
-		cmd = conf_get_str_value (BROWSER_COMMAND);
-	} else {
-		/* non manual browser definitions... */
-		if (browser) {
-			if (remote) {
-				switch (place) {
-					case 1:
-						cmd = browser->existingwinremote;
-						break;
-					case 2:
-						cmd = browser->newwinremote;
-						break;
-					case 3:
-						cmd = browser->newtabremote;
-						break;
-				}
-			} else {
-				switch (place) {
-					case 1:
-						cmd = browser->existingwin;
-						break;
-					case 2:
-						cmd = browser->newwin;
-						break;
-					case 3:
-						cmd = browser->newtab;
-						break;
-				}
-			}
-
-			if (fallback && !cmd)	/* Default when no special mode defined */
-				cmd = browser->defaultplace;
-		}
-
-		if (fallback && !cmd)	/* Last fallback: first browser default */
-			cmd = browsers[0].defaultplace;
-	}
-	g_free (libname);
-		
-	return cmd?g_strdup (cmd):NULL;
-}
-
-struct browser *
-prefs_get_browser (void)
-{
-	gchar		*libname;
-	struct browser	*browser = NULL;
-	
-	libname = conf_get_str_value (BROWSER_ID);
-	if (!g_str_equal (libname, "manual")) {
-		struct browser *iter;
-		for (iter = browsers; iter->id != NULL; iter++) {
-			if (g_str_equal (libname, iter->id))
-				browser = iter;
-		}
-	}
-	g_free (libname);
-
-	return browser;
-}
-
 enclosureDownloadToolPtr
 prefs_get_download_tool (void)
 {
+	gint	enclosure_download_tool;
+
+	conf_get_int_value (ENCLOSURE_DOWNLOAD_TOOL, &enclosure_download_tool);
+
 	/* FIXME: array boundary check */
-	return &(enclosure_download_commands[conf_get_int_value (ENCLOSURE_DOWNLOAD_TOOL)]);
+	return &(enclosure_download_commands[enclosure_download_tool]);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -236,17 +122,38 @@ on_folderdisplaybtn_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 	conf_set_int_value(FOLDER_DISPLAY_MODE, (TRUE == enabled)?1:0);
 }
 
+/**
+ * The "Hide read items" button has been clicked. Here we change the
+ * preference and, if the selected node is a folder, we reload the
+ * itemlist. Also, if there was an item selected, we add it to the
+ * itemlist and select it, since when the itemlist is unloaded and loaded,
+ * no item will be selected at all.
+ */
 void
 on_folderhidereadbtn_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 {
-	nodePtr	displayedNode;
+	nodePtr		displayedNode;
+	itemPtr		displayedItem;
+	gboolean	enabled;
 
-	gboolean enabled = gtk_toggle_button_get_active (togglebutton);
-	conf_set_bool_value (FOLDER_DISPLAY_HIDE_READ, enabled);
 	displayedNode = itemlist_get_displayed_node ();
-	if (displayedNode) {
+	displayedItem = itemlist_get_selected ();
+
+	enabled = gtk_toggle_button_get_active (togglebutton);
+	conf_set_bool_value (FOLDER_DISPLAY_HIDE_READ, enabled);
+
+	if (displayedNode && IS_FOLDER (displayedNode)) {
 		itemlist_unload (FALSE);
 		itemlist_load (displayedNode);
+
+		/* After the itemlist is reloaded, no item is selected,
+		 * so we manually select the old one.
+		 */
+		if (displayedItem) {
+			itemview_add_item (displayedItem);
+			itemview_select_item (displayedItem);
+			item_unload (displayedItem);
+		}
 	}
 }
 
@@ -265,13 +172,13 @@ on_popupwindowsoptionbtn_clicked (GtkButton *button, gpointer user_data)
 {
 	gboolean enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 	conf_set_bool_value (SHOW_POPUP_WINDOWS, enabled);
-	notification_enable (conf_get_bool_value (SHOW_POPUP_WINDOWS));
 }
 
-static void
-on_feed_startup_update_changed (gpointer user_data)
+void
+on_startupactionbtn_toggled (GtkButton *button, gpointer user_data)
 {
-	conf_set_int_value (STARTUP_FEED_ACTION, gtk_combo_box_get_active (GTK_COMBO_BOX (liferea_dialog_lookup (prefdialog, "startupActionCombo"))));
+	gboolean enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+	conf_set_int_value (STARTUP_FEED_ACTION, enabled?0:1);
 }
 
 void
@@ -281,23 +188,29 @@ on_browsercmd_changed (GtkEditable *editable, gpointer user_data)
 }
 
 static void
-on_browser_changed (GtkOptionMenu *optionmenu, gpointer user_data)
+on_browser_changed (GtkComboBox *optionmenu, gpointer user_data)
 {
-	gint num = GPOINTER_TO_INT (user_data);
+	GtkTreeIter	iter;
+	gint		num = -1;
+	struct browser	*browsers = browser_get_all();
+	
+	if (gtk_combo_box_get_active_iter (optionmenu, &iter)) {
+		gtk_tree_model_get (gtk_combo_box_get_model (optionmenu), &iter, 1, &num, -1);
 
-	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "browsercmd"), browsers[num].id == NULL);	
-	gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "manuallabel"), browsers[num].id == NULL);	
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "browsercmd"), browsers[num].id == NULL);	
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "manuallabel"), browsers[num].id == NULL);	
 
-	if (browsers[num].id == NULL)
-		conf_set_str_value (BROWSER_ID, "manual");
-	else
-		conf_set_str_value (BROWSER_ID, browsers[num].id);
+		if (browsers[num].id == NULL)
+			conf_set_str_value (BROWSER_ID, "manual");
+		else
+			conf_set_str_value (BROWSER_ID, browsers[num].id);
+	}
 }
 
 static void
-on_browser_place_changed (GtkOptionMenu *optionmenu, gpointer user_data)
+on_browser_place_changed (GtkComboBox *optionmenu, gpointer user_data)
 {
-	int num = GPOINTER_TO_INT (user_data);
+	int num = gtk_combo_box_get_active (optionmenu);
 	
 	conf_set_int_value (BROWSER_PLACE, num);
 }
@@ -321,15 +234,14 @@ on_enableplugins_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 }
 
 static void
-on_socialsite_changed (GtkOptionMenu *optionmenu, gpointer user_data)
+on_socialsite_changed (GtkComboBox *optionmenu, gpointer user_data)
 {
-	social_set_bookmark_site ((gchar *)user_data);
-}
-
-static void
-on_linksearchsite_changed (GtkOptionMenu *optionmenu, gpointer user_data)
-{
-	social_set_link_search_site ((gchar *)user_data);
+	GtkTreeIter iter;
+	if (gtk_combo_box_get_active_iter (optionmenu, &iter)) {
+		gchar * site;
+		gtk_tree_model_get (gtk_combo_box_get_model (optionmenu), &iter, 0, &site, -1);
+		social_set_bookmark_site (site);
+	}
 }
 
 static void
@@ -378,34 +290,6 @@ on_default_update_interval_unit_changed (gpointer user_data)
 	on_default_update_interval_value_changed (NULL, NULL);
 }
 
-/*
-void
-on_menuselection_clicked (GtkButton *button, gpointer user_data)
-{
-	gint active_button;
-	
-	active_button = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT(button), "option_number"));
-	switch (active_button) {
-		case 1:
-			conf_set_bool_value (DISABLE_MENUBAR, FALSE);
-			conf_set_bool_value (DISABLE_TOOLBAR, FALSE);
-			break;
-		case 2:
-			conf_set_bool_value (DISABLE_MENUBAR, FALSE);
-			conf_set_bool_value (DISABLE_TOOLBAR, TRUE);
-			break;
-		case 3:
-			conf_set_bool_value (DISABLE_MENUBAR, TRUE);
-			conf_set_bool_value (DISABLE_TOOLBAR, FALSE);
-			break;
-		default:
-			break;
-	}
-	
-	liferea_shell_update_menubar ();
-	liferea_shell_update_toolbar ();
-}*/
-
 static void
 on_updateallfavicons_clicked (GtkButton *button, gpointer user_data)
 {
@@ -441,25 +325,25 @@ on_useProxyAuth_toggled (GtkToggleButton *button, gpointer user_data)
 	conf_set_bool_value (PROXY_USEAUTH, enabled);
 }
 
-void
+static void
 on_proxyhostentry_changed (GtkEditable *editable, gpointer user_data)
 {
 	conf_set_str_value (PROXY_HOST, gtk_editable_get_chars (editable,0,-1));
 }
 
-void
+static void
 on_proxyportentry_changed (GtkEditable *editable, gpointer user_data)
 {
 	conf_set_int_value (PROXY_PORT, atoi (gtk_editable_get_chars (editable,0,-1)));
 }
 
-void
+static void
 on_proxyusernameentry_changed (GtkEditable *editable, gpointer user_data)
 {
 	conf_set_str_value (PROXY_USER, gtk_editable_get_chars (editable,0,-1));
 }
 
-void
+static void
 on_proxypasswordentry_changed (GtkEditable *editable, gpointer user_data)
 {
 	conf_set_str_value (PROXY_PASSWD, gtk_editable_get_chars (editable,0,-1));
@@ -578,7 +462,10 @@ static void ui_pref_destroyed_cb(GtkWidget *widget, void *data) {
 }
 
 void on_prefbtn_clicked(void) {
-	GtkWidget		*widget, *entry, *menu;
+	GtkWidget		*widget, *entry;
+	GtkComboBox		*combo;
+	GtkListStore		*store;
+	GtkTreeIter		treeiter;
 	GtkAdjustment		*itemCount;
 	GtkTreeStore		*treestore;
 	GtkTreeViewColumn 	*column;
@@ -588,66 +475,70 @@ void on_prefbtn_clicked(void) {
 	gboolean		enabled;
 	int			tmp, i;
 	static int		manual;
-	struct browser			*iter;
+	struct browser		*iter;
+	gint			startup_feed_update, default_max_items;
+	gint			folder_display_mode, browse_key_setting;
+	gint			proxy_port, browser_place;
+	gint			enclosure_download_tool;
+	gboolean		folder_display_hide_read, disable_javascript;
+	gboolean		browse_inside_application, enable_plugins;
+	gboolean		show_tray_icon, show_popup_windows;
+	gboolean		show_new_count_in_tray, dont_minimize_to_tray;
+	gboolean		start_in_tray, disable_toolbar;
+	gchar			*proxy_host, *proxy_user, *proxy_passwd;
+	gchar			*browser_command, *enclosure_download_path;
 	
 	if (!prefdialog) {
 		prefdialog = liferea_dialog_new (NULL, "prefdialog");
 		g_signal_connect (G_OBJECT (prefdialog), "destroy", G_CALLBACK (ui_pref_destroyed_cb), NULL);
 
 		/* Set up browser selection popup */
-		menu = gtk_menu_new();
-		for(i=0, iter = browsers; iter->id != NULL; iter++, i++) {
-			entry = gtk_menu_item_new_with_label(_(iter->display));
-			gtk_widget_show(entry);
-			gtk_container_add(GTK_CONTAINER(menu), entry);
-			g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_changed), GINT_TO_POINTER(i));
+		store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
+		for(i=0, iter = browser_get_all (); iter->id != NULL; iter++, i++) {
+			gtk_list_store_append (store, &treeiter);
+			gtk_list_store_set (store, &treeiter, 0, _(iter->display), 1, i, -1);
 		}
 		manual = i;
 		/* This allows the user to choose their own browser by typing in the command. */
-		entry = gtk_menu_item_new_with_label(_("Manual"));
-		gtk_widget_show(entry);
-		gtk_container_add(GTK_CONTAINER(menu), entry);
-		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_changed), GINT_TO_POINTER(i));
+		gtk_list_store_append (store, &treeiter);
+		gtk_list_store_set (store, &treeiter, 0, _("Manual"), 1, i, -1);
+		combo = GTK_COMBO_BOX(liferea_dialog_lookup(prefdialog, "browserpopup"));
+		gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
+		ui_common_setup_combo_text (combo, 0);
+		g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(on_browser_changed), NULL);
+ 
+ 		/* Create location menu */
+		store = gtk_list_store_new (1, G_TYPE_STRING);
 
-		gtk_option_menu_set_menu(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "browserpopup")), menu);
-
-		/* Create location menu */
-		menu = gtk_menu_new();
-
-		entry = gtk_menu_item_new_with_label(_("Browser default"));
-		gtk_widget_show(entry);
-		gtk_container_add(GTK_CONTAINER(menu), entry);
-		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(0));
-
-		entry = gtk_menu_item_new_with_label(_("Existing window"));
-		gtk_widget_show(entry);
-		gtk_container_add(GTK_CONTAINER(menu), entry);
-		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(1));
-
-		entry = gtk_menu_item_new_with_label(_("New window"));
-		gtk_widget_show(entry);
-		gtk_container_add(GTK_CONTAINER(menu), entry);
-		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(2));
-
-		entry = gtk_menu_item_new_with_label(_("New tab"));
-		gtk_widget_show(entry);
-		gtk_container_add(GTK_CONTAINER(menu), entry);
-		g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(on_browser_place_changed), GINT_TO_POINTER(3));
-
-		gtk_option_menu_set_menu(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "browserlocpopup")), menu);
+		combo = GTK_COMBO_BOX(liferea_dialog_lookup(prefdialog, "browserlocpopup"));
+		gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
+		ui_common_setup_combo_text (combo, 0);
+		g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(on_browser_place_changed), NULL);
+ 
+		gtk_list_store_append (store, &treeiter);
+		gtk_list_store_set (store, &treeiter, 0, _("Browser default"), -1);
+ 
+		gtk_list_store_append (store, &treeiter);
+		gtk_list_store_set (store, &treeiter, 0, _("Existing window"), -1);
+ 
+		gtk_list_store_append (store, &treeiter);
+		gtk_list_store_set (store, &treeiter, 0, _("New window"), -1);
+ 
+		gtk_list_store_append (store, &treeiter);
+		gtk_list_store_set (store, &treeiter, 0, _("New tab"), -1);
+ 
 
 		/* ================== panel 1 "feeds" ==================== */
 
-		/* menu for feed startup update action */
-		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "startupActionCombo"),
-		                            startup_update_options, 
-		                            G_CALLBACK (on_feed_startup_update_changed),
-		                            conf_get_int_value(STARTUP_FEED_ACTION));
+		/* check box for feed startup update */
+		conf_get_int_value (STARTUP_FEED_ACTION, &startup_feed_update);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (prefdialog, "startupactionbtn")), (startup_feed_update == 0)); 
 
 		/* cache size setting */
 		widget = liferea_dialog_lookup (prefdialog, "itemCountBtn");
 		itemCount = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (widget));
-		gtk_adjustment_set_value (itemCount, conf_get_int_value (DEFAULT_MAX_ITEMS));
+		conf_get_int_value (DEFAULT_MAX_ITEMS, &default_max_items);
+		gtk_adjustment_set_value (itemCount, default_max_items);
 
 		/* set default update interval spin button and unit combo box */
 		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "globalRefreshIntervalUnitComboBox"),
@@ -656,7 +547,7 @@ void on_prefbtn_clicked(void) {
 					    -1);
 					   
 		widget = liferea_dialog_lookup (prefdialog, "globalRefreshIntervalUnitComboBox");
-		tmp = conf_get_int_value (DEFAULT_UPDATE_INTERVAL);
+		conf_get_int_value (DEFAULT_UPDATE_INTERVAL, &tmp);
 		if (tmp % 1440 == 0) {		/* days */
 			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 2);
 			tmp /= 1440;
@@ -672,116 +563,137 @@ void on_prefbtn_clicked(void) {
 
 		/* ================== panel 2 "folders" ==================== */
 
-		g_signal_connect(GTK_OBJECT(liferea_dialog_lookup(prefdialog, "updateAllFavicons")), "clicked", G_CALLBACK(on_updateallfavicons_clicked), NULL);	
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(prefdialog, "folderdisplaybtn")), (0 == conf_get_int_value(FOLDER_DISPLAY_MODE)?FALSE:TRUE));
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(prefdialog, "hidereadbtn")), (0 == conf_get_bool_value(FOLDER_DISPLAY_HIDE_READ)?FALSE:TRUE));
+		g_signal_connect(GTK_OBJECT(liferea_dialog_lookup(prefdialog, "updateAllFavicons")), "clicked", G_CALLBACK(on_updateallfavicons_clicked), NULL);
+
+		conf_get_int_value (FOLDER_DISPLAY_MODE, &folder_display_mode);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(prefdialog, "folderdisplaybtn")), folder_display_mode?TRUE:FALSE);
+		conf_get_bool_value (FOLDER_DISPLAY_HIDE_READ, &folder_display_hide_read);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(liferea_dialog_lookup(prefdialog, "hidereadbtn")), folder_display_hide_read?TRUE:FALSE);
 
 		/* ================== panel 3 "headlines" ==================== */
 
+		conf_get_int_value (BROWSE_KEY_SETTING, &browse_key_setting);
 		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "skimKeyCombo"),
 		                            browser_skim_key_options,
 		                            G_CALLBACK (on_skim_key_changed),
-		                            conf_get_int_value (BROWSE_KEY_SETTING));
+		                            browse_key_setting);
 					  
 		/* Setup social bookmarking list */
 		i = 0;
-		name = conf_get_str_value (SOCIAL_BM_SITE);
-		menu = gtk_menu_new ();
+		conf_get_str_value (SOCIAL_BM_SITE, &name);
+		store = gtk_list_store_new (1, G_TYPE_STRING);
 		list = bookmarkSites;
 		while (list) {
 			socialSitePtr siter = list->data;
 			if (name && !strcmp (siter->name, name))
 				tmp = i;
-			entry = gtk_menu_item_new_with_label (siter->name);
-			gtk_widget_show (entry);
-			gtk_container_add (GTK_CONTAINER (menu), entry);
-			g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (on_socialsite_changed), (gpointer)siter->name);
+			gtk_list_store_append (store, &treeiter);
+			gtk_list_store_set (store, &treeiter, 0, siter->name, -1);
 			list = g_slist_next (list);
 			i++;
 		}
-		gtk_option_menu_set_menu (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "socialpopup")), menu);
-		gtk_option_menu_set_history (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "socialpopup")), tmp);
-		
-		/* Setup link cosmos search engine list */
-		i = 0;
-		name = conf_get_str_value (SOCIAL_LINK_SEARCH_SITE);
-		menu = gtk_menu_new ();
-		list = linkSearchSites;
-		while (list) {
-			socialSitePtr siter = list->data;
-			if (name && !strcmp (siter->name, name))
-				tmp = i;
-			entry = gtk_menu_item_new_with_label (siter->name);
-			gtk_widget_show (entry);
-			gtk_container_add (GTK_CONTAINER (menu), entry);
-			g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (on_linksearchsite_changed), (gpointer)siter->name);
-			list = g_slist_next (list);
-			i++;
-		}
-		gtk_option_menu_set_menu (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "searchpopup")), menu);
-		gtk_option_menu_set_history (GTK_OPTION_MENU (liferea_dialog_lookup (prefdialog, "searchpopup")), tmp);
-		
+
+		combo = GTK_COMBO_BOX (liferea_dialog_lookup (prefdialog, "socialpopup"));
+		g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (on_socialsite_changed), NULL);
+		gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
+		ui_common_setup_combo_text (combo, 0);
+		gtk_combo_box_set_active (combo, tmp);
 
 		/* ================== panel 4 "browser" ==================== */
 
 		/* set the inside browsing flag */
 		widget = liferea_dialog_lookup(prefdialog, "browseinwindow");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(BROWSE_INSIDE_APPLICATION));
+		conf_get_bool_value(BROWSE_INSIDE_APPLICATION, &browse_inside_application);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), browse_inside_application);
 
 		/* set the javascript-disabled flag */
 		widget = liferea_dialog_lookup(prefdialog, "disablejavascript");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(DISABLE_JAVASCRIPT));
+		conf_get_bool_value(DISABLE_JAVASCRIPT, &disable_javascript);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), disable_javascript);
 		
 		/* set the enable Plugins flag */
 		widget = liferea_dialog_lookup(prefdialog, "enableplugins");
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), conf_get_bool_value(ENABLE_PLUGINS));
+		conf_get_bool_value(ENABLE_PLUGINS, &enable_plugins);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), enable_plugins);
 
 		tmp = 0;
-		configuredBrowser = conf_get_str_value(BROWSER_ID);
+		conf_get_str_value(BROWSER_ID, &configuredBrowser);
 
 		if(!strcmp(configuredBrowser, "manual"))
 			tmp = manual;
 		else
-			for(i=0, iter = browsers; iter->id != NULL; iter++, i++)
+			for(i=0, iter = browser_get_all (); iter->id != NULL; iter++, i++)
 				if(!strcmp(configuredBrowser, iter->id))
 					tmp = i;
 
-		gtk_option_menu_set_history(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "browserpopup")), tmp);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(liferea_dialog_lookup(prefdialog, "browserpopup")), tmp);
 		g_free(configuredBrowser);
 
-		gtk_option_menu_set_history(GTK_OPTION_MENU(liferea_dialog_lookup(prefdialog, "browserlocpopup")), conf_get_int_value(BROWSER_PLACE));
+		conf_get_int_value (BROWSER_PLACE, &browser_place);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(liferea_dialog_lookup(prefdialog, "browserlocpopup")), browser_place);
 
+		conf_get_str_value (BROWSER_COMMAND, &browser_command);
 		entry = liferea_dialog_lookup(prefdialog, "browsercmd");
-		gtk_entry_set_text(GTK_ENTRY(entry), conf_get_str_value(BROWSER_COMMAND));
+		gtk_entry_set_text(GTK_ENTRY(entry), browser_command);
+		g_free (browser_command);
+
 		gtk_widget_set_sensitive(GTK_WIDGET(entry), tmp==manual);
 		gtk_widget_set_sensitive(liferea_dialog_lookup(prefdialog, "manuallabel"), tmp==manual);	
 
 		/* ================== panel 4 "GUI" ================ */
 
+		conf_get_bool_value (SHOW_TRAY_ICON, &show_tray_icon);
+
 		widget = liferea_dialog_lookup (prefdialog, "popupwindowsoptionbtn");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (SHOW_POPUP_WINDOWS));
+		conf_get_bool_value (SHOW_POPUP_WINDOWS, &show_popup_windows);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), show_popup_windows);
 		
 		widget = liferea_dialog_lookup (prefdialog, "trayiconoptionbtn");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (SHOW_TRAY_ICON));
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), show_tray_icon);
 
 		widget = liferea_dialog_lookup (prefdialog, "newcountintraybtn");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (SHOW_NEW_COUNT_IN_TRAY));
-		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "newcountintraybtn"), conf_get_bool_value (SHOW_TRAY_ICON));
+		conf_get_bool_value (SHOW_NEW_COUNT_IN_TRAY, &show_new_count_in_tray);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), show_new_count_in_tray);
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "newcountintraybtn"), show_tray_icon);
 
 		widget = liferea_dialog_lookup (prefdialog, "minimizetotraybtn");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (DONT_MINIMIZE_TO_TRAY));
-		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "minimizetotraybtn"), conf_get_bool_value (SHOW_TRAY_ICON));
+		conf_get_bool_value (DONT_MINIMIZE_TO_TRAY, &dont_minimize_to_tray);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), dont_minimize_to_tray);
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "minimizetotraybtn"), show_tray_icon);
 		
 		widget = liferea_dialog_lookup (prefdialog, "startintraybtn");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value (START_IN_TRAY));
-		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "startintraybtn"), conf_get_bool_value (SHOW_TRAY_ICON));
+		conf_get_bool_value (START_IN_TRAY, &start_in_tray);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), start_in_tray);
+		gtk_widget_set_sensitive (liferea_dialog_lookup (prefdialog, "startintraybtn"), show_tray_icon);
+
+		if (ui_indicator_is_visible ()) {
+			/*
+			   If we use the indicator applet:
+			   - The "show tray icon" and "minimize to tray icon" settings
+			     are interpreted as "show indicator" and "minimize to indicator"
+			   - The "new count in tray icon" setting doesn't make sense and
+			     is ignored by indicator handling code
+			*/
+			
+			gtk_widget_hide (liferea_dialog_lookup (prefdialog, "newcountintraybtn"));
+			
+			gtk_button_set_label (GTK_BUTTON (liferea_dialog_lookup (prefdialog, "trayiconoptionbtn")),
+				_("Integrate with the messaging menu (indicator)"));
+			
+			gtk_button_set_label (GTK_BUTTON (liferea_dialog_lookup (prefdialog, "minimizetotraybtn")),
+				_("Terminate instead of minimizing to the messaging menu"));
+			
+			gtk_button_set_label (GTK_BUTTON (liferea_dialog_lookup (prefdialog, "startintraybtn")),
+				_("Start minimized to the messaging menu"));
+		}
 
 		/* tool bar settings */	
 		widget = liferea_dialog_lookup (prefdialog, "hidetoolbarbtn");
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), conf_get_bool_value(DISABLE_TOOLBAR));
+		conf_get_bool_value(DISABLE_TOOLBAR, &disable_toolbar);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), disable_toolbar);
 
 		/* select currently active toolbar style option */
-		name = conf_get_str_value (TOOLBAR_STYLE);
+		conf_get_str_value (TOOLBAR_STYLE, &name);
 		for (i = 0; gui_toolbar_style_values[i] != NULL; ++i) {
 			if (strcmp (name, gui_toolbar_style_values[i]) == 0)
 				break;
@@ -799,18 +711,29 @@ void on_prefbtn_clicked(void) {
 		                            i);
 
 		/* ================= panel 5 "proxy" ======================== */
-		proxyport = g_strdup_printf ("%d", conf_get_int_value (PROXY_PORT));
-		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "proxyhostentry")), conf_get_str_value(PROXY_HOST));
+		conf_get_str_value (PROXY_HOST, &proxy_host);
+		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "proxyhostentry")), proxy_host);
+		g_free (proxy_host);
+
+		conf_get_int_value (PROXY_PORT, &proxy_port);
+		proxyport = g_strdup_printf ("%d", proxy_port);
 		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "proxyportentry")), proxyport);
 		g_free (proxyport);
 
-		enabled = conf_get_bool_value (PROXY_USEAUTH);
+		conf_get_bool_value (PROXY_USEAUTH, &enabled);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (prefdialog, "useProxyAuth")), enabled);
-		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "proxyusernameentry")), conf_get_str_value (PROXY_USER));
-		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "proxypasswordentry")), conf_get_str_value (PROXY_PASSWD));
+
+		conf_get_str_value (PROXY_USER, &proxy_user);
+		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "proxyusernameentry")), proxy_user);
+		g_free (proxy_user);
+
+		conf_get_str_value (PROXY_PASSWD, &proxy_passwd);
+		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "proxypasswordentry")), proxy_passwd);
+		g_free (proxy_passwd);
+
 		gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup(prefdialog, "proxyauthtable")), enabled);
 			
-		i = conf_get_int_value (PROXY_DETECT_MODE);
+		conf_get_int_value (PROXY_DETECT_MODE, &i);
 		switch (i) {
 			default:
 			case 0: /* proxy auto detect */
@@ -838,13 +761,16 @@ void on_prefbtn_clicked(void) {
 		/* ================= panel 6 "enclosures" ======================== */
 
 		/* menu for download tool */
+		conf_get_int_value (ENCLOSURE_DOWNLOAD_TOOL, &enclosure_download_tool);
 		ui_common_setup_combo_menu (liferea_dialog_lookup (prefdialog, "downloadToolCombo"),
 		                            enclosure_download_tool_options,
 		                            G_CALLBACK (on_enclosure_download_tool_changed),
-		                            conf_get_int_value (ENCLOSURE_DOWNLOAD_TOOL));
+		                            enclosure_download_tool);
 
-		/* set enclosure download path entry */	
-		gtk_entry_set_text(GTK_ENTRY(liferea_dialog_lookup(prefdialog, "save_download_entry")), conf_get_str_value(ENCLOSURE_DOWNLOAD_PATH));
+		/* set enclosure download path entry */
+		conf_get_str_value (ENCLOSURE_DOWNLOAD_PATH, &enclosure_download_path);
+		gtk_entry_set_text(GTK_ENTRY(liferea_dialog_lookup(prefdialog, "save_download_entry")), enclosure_download_path);
+		g_free (enclosure_download_path);
 
 		/* set up list of configured enclosure types */
 		treestore = gtk_tree_store_new(FTS_LEN, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
@@ -873,12 +799,14 @@ void on_prefbtn_clicked(void) {
 		gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(widget)), GTK_SELECTION_SINGLE);
 
 		/* ================= panel 7 "sync" ======================== */
+		/* FIXME: Avahi Sync is not yet imlemented
 
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (prefdialog, "useAvahiSync")), conf_get_bool_value (SYNC_AVAHI_ENABLED));
 		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "avahiServiceNameEntry")), conf_get_str_value (SYNC_AVAHI_SERVICE_NAME));		
 		gtk_entry_set_text (GTK_ENTRY (liferea_dialog_lookup (prefdialog, "avahiServicePasswordEntry")), conf_get_str_value (SYNC_AVAHI_PASSWORD));
 		gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog, "avahiServiceNameEntry")), conf_get_bool_value (SYNC_AVAHI_ENABLED));
 		gtk_widget_set_sensitive (GTK_WIDGET (liferea_dialog_lookup (prefdialog, "avahiServicePasswordEntry")), conf_get_bool_value (SYNC_AVAHI_ENABLED));
+		*/
 	}	
 	gtk_window_present(GTK_WINDOW(prefdialog));
 }
