@@ -22,10 +22,6 @@
 
 #include "update.h"
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
 #include <libxml/parser.h>
 #include <libxslt/xslt.h>
 #include <libxslt/xsltInternals.h>
@@ -37,37 +33,21 @@
 #include <sys/wait.h>
 #include <string.h>
 
-#ifdef USE_NM
-#include <dbus/dbus.h>
-#include <libnm_glib.h>
-#endif
-
 #include "common.h"
-#include "conf.h"
 #include "debug.h"
 #include "net.h"
 #include "xml.h"
-#include "ui/liferea_htmlview.h"
 #include "ui/liferea_shell.h"
 #include "ui/ui_tray.h"
 
 /** global update job list, used for lookups when cancelling */
 static GSList	*jobs = NULL;
 
-/* We use a communication queue for limiting the number 
-   of concurrent requests to avoid hitting the file descriptor
-   limit of the glibcurl code. */
 static GAsyncQueue *pendingHighPrioJobs = NULL;
 static GAsyncQueue *pendingJobs = NULL;
 static guint numberOfActiveJobs = 0;
 #define MAX_ACTIVE_JOBS	5
 
-#ifdef USE_NM
-/* State for NM support */
-static libnm_glib_ctx *nm_ctx = NULL;
-static guint nm_id = 0;
-#endif
-
 /* update state interface */
 
 updateStatePtr
@@ -321,7 +301,7 @@ update_apply_xslt (updateJobPtr job)
 	g_assert (NULL != job->result);
 	
 	do {
-		srcDoc = xml_parse (job->result->data, job->result->size, FALSE, NULL);
+		srcDoc = xml_parse (job->result->data, job->result->size, NULL);
 		if (!srcDoc) {
 			g_warning("fatal: parsing request result XML source failed (%s)!", job->request->filtercmd);
 			break;
@@ -490,8 +470,9 @@ update_dequeue_job (gpointer user_data)
 	if (!pendingJobs)
 		return FALSE;	/* we must be in shutdown */
 		
-	if (numberOfActiveJobs >= MAX_ACTIVE_JOBS)
-		return TRUE;	/* let's continue later */
+	if (numberOfActiveJobs >= MAX_ACTIVE_JOBS) 
+		return FALSE;	/* we'll be called again when a job finishes */
+	
 
 	job = (updateJobPtr)g_async_queue_try_pop(pendingHighPrioJobs);
 
@@ -499,7 +480,7 @@ update_dequeue_job (gpointer user_data)
 		job = (updateJobPtr)g_async_queue_try_pop(pendingJobs);
 
 	if(!job)
-		return TRUE;	/* no request at the moment */
+		return FALSE;	/* no request at the moment */
 
 	numberOfActiveJobs++;
 
@@ -512,7 +493,7 @@ update_dequeue_job (gpointer user_data)
 		update_job_run (job);
 	}
 		
-	return TRUE;
+	return TRUE; /* since I got a job now, there may be more in the queue */
 }
 
 updateJobPtr
@@ -532,11 +513,11 @@ update_execute_request (gpointer owner,
 
 	if (flags & FEED_REQ_PRIORITY_HIGH) {
 		g_async_queue_push (pendingHighPrioJobs, (gpointer)job);
-		update_dequeue_job (NULL);
 	} else {
 		g_async_queue_push (pendingJobs, (gpointer)job);
 	}
 
+	g_idle_add (update_dequeue_job, NULL);
 	return job;
 }
 
@@ -573,6 +554,7 @@ update_process_finished_job (updateJobPtr job)
 	
 	g_assert(numberOfActiveJobs > 0);
 	numberOfActiveJobs--;
+	g_idle_add (update_dequeue_job, NULL);
 
 	/* Handling abandoned requests (e.g. after feed deletion) */
 	if (job->callback == NULL) {	
@@ -588,91 +570,12 @@ update_process_finished_job (updateJobPtr job)
 	g_idle_add (update_process_result_idle_cb, job);
 }
 
-#ifdef USE_NM
-static void
-update_network_monitor (libnm_glib_ctx *ctx, gpointer user_data)
-{
-	libnm_glib_state	state;
-	gboolean online;
-
-	g_return_if_fail (ctx != NULL);
-
-	state = libnm_glib_get_network_state (ctx);
-	online = network_is_online ();
-
-	if (online && state == LIBNM_NO_NETWORK_CONNECTION) {
-		debug0 (DEBUG_UPDATE, "network manager: no network connection -> going offline");
-		network_set_online (FALSE);
-	} else if (!online && state == LIBNM_ACTIVE_NETWORK_CONNECTION) {
-		debug0 (DEBUG_UPDATE, "network manager: active connection -> going online");
-		network_set_online (TRUE);
-	}
-}
-
-static gboolean
-update_nm_initialize (void)
-{
-	debug0 (DEBUG_UPDATE, "network manager: registering network state change callback");
-	
-	if (!nm_ctx) {
-		nm_ctx = libnm_glib_init ();
-		if (!nm_ctx) {
-			fprintf (stderr, "Could not initialize libnm.\n");
-			return FALSE;
-		}	
-	}
-
-	nm_id = libnm_glib_register_callback (nm_ctx, update_network_monitor, NULL, NULL);
-	
-	return TRUE;
-}
-
-static void
-update_nm_cleanup (void)
-{
-	debug0 (DEBUG_UPDATE, "network manager: unregistering network state change callback");
-	
-	if (nm_id != 0 && nm_ctx != NULL) {
-		libnm_glib_unregister_callback (nm_ctx, nm_id);
-		libnm_glib_shutdown (nm_ctx);
-		nm_ctx = NULL;
-		nm_id = 0;
-	}
-}
-#endif
 
 void
 update_init (void)
 {
 	pendingJobs = g_async_queue_new ();
 	pendingHighPrioJobs = g_async_queue_new ();
-	network_init ();
-	
-	g_timeout_add (500, update_dequeue_job, NULL);
-	
-#ifdef USE_NM
-	{
-		DBusConnection *connection;
-
-		connection = dbus_bus_get (DBUS_BUS_SYSTEM, NULL);
-
-		if (connection) {
-			dbus_connection_set_exit_on_disconnect (connection, FALSE);
-
-			if (dbus_bus_name_has_owner (connection, "org.freedesktop.NetworkManager", NULL)) {
-				update_nm_initialize ();
-				/* network manager will set online state right after initialization... */
-			} else {
-				network_set_online (TRUE);
-			}
-
-			dbus_connection_unref(connection);
-
-			return;
-		}
-	}
-#endif
-	network_set_online (TRUE);
 }
 
 void
@@ -680,13 +583,6 @@ update_deinit (void)
 {
 	GSList	*iter = jobs;
 
-	debug_enter ("update_deinit");
-
-#ifdef USE_NM	
-	update_nm_cleanup ();
-#endif	
-	network_deinit ();
-	
 	/* Cancel all jobs, to avoid async callbacks accessing the GUI */
 	while (iter) {
 		updateJobPtr job = (updateJobPtr)iter->data;
@@ -699,6 +595,4 @@ update_deinit (void)
 	
 	g_slist_free (jobs);
 	jobs = NULL;
-	
-	debug_exit ("update_deinit");
 }
